<?php

namespace MotoPress\Appointment\AdminPages\Custom;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class CalendarPage extends AbstractCustomPage {


	public function addActions() {
		parent::addActions();
		add_action( 'admin_body_class', array( $this, 'addPageClass' ) );
		add_action( 'wp_ajax_current-user-can-edit-others-mpa-bookings', array( $this, 'wpAjaxCurrentUserCanEditOthersMpaBookings' ) );
	}

	public function addPageClass( $classes ) {
		$pageClass = 'appointments_page_mpa_calendar';
		if ( strpos( $classes, $pageClass ) === false ) {
			$classes .= ' ' . $pageClass;
		}

		return $classes;
	}

	public function wpAjaxCurrentUserCanEditOthersMpaBookings() {
		check_ajax_referer( 'wp_rest', 'nonce_code' );

		if ( current_user_can( 'edit_others_mpa_bookings' ) ) {
			wp_die( true );
		}

		wp_die( false );
	}

	protected function enqueueScripts() {
		mpapp()->assets()->enqueueBundle( 'mpa-calendar-page' );
		mpa_assets()->enqueueStyle( '' );
		$this->localizeScripts();
	}

	/**
	 * @access protected
	 */
	public function display() {
		echo '<div class="wrap">';
			echo '<div id="app"></div>';
		echo '</div>';
	}

	/**
	 * @return string
	 */
	protected function getPageTitle() {
		return esc_html__( 'Calendar', 'motopress-appointment' );
	}

	/**
	 * @return string
	 */
	protected function getMenuTitle() {
		return esc_html__( 'Calendar', 'motopress-appointment' );
	}

	protected function localizeScripts() {
		wp_localize_script(
			'mpa-calendar-page',
			'MPA_CALENDAR_REST_API_DATA',
			array(
				'root'  => esc_url_raw( rest_url() ),
				'nonce' => wp_create_nonce( 'wp_rest' ),
			)
		);
		wp_localize_script(
			'mpa-calendar-page',
			'MPA_CALENDAR_URLS',
			array(
				'admin' => admin_url(),
			)
		);
		wp_localize_script(
			'mpa-calendar-page',
			'MPA_CALENDAR_SETTINGS',
			array(
				'start_of_week' => get_option( 'start_of_week', 0 ),
			)
		);
	}
}
