<?php

namespace MotoPress\Appointment\AdminPages\Manage;

use MotoPress\Appointment\Entities\Booking;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.0
 */
class ManageBookingsPage extends ManagePostsPage {

	/**
	 * @since 1.0
	 */
	protected function enqueueScripts() {
		mpa_assets()->enqueueStyle( 'mpa-manage-posts' );
	}

	/**
	 * @return array
	 *
	 * @since 1.0
	 */
	protected function customColumns() {
		$isMultibooking = mpapp()->settings()->isMultibookingEnabled();

		return array(
			'status'    => esc_html__( 'Status', 'motopress-appointment' ),
			'customer'  => esc_html__( 'Customer', 'motopress-appointment' ),
			'price'     => esc_html__( 'Price', 'motopress-appointment' ),
			'services'  => $isMultibooking ? esc_html__( 'Services', 'motopress-appointment' ) : esc_html__( 'Service', 'motopress-appointment' ),
			'employees' => $isMultibooking ? esc_html__( 'Employees', 'motopress-appointment' ) : esc_html__( 'Employee', 'motopress-appointment' ),
			'time'      => esc_html__( 'Time', 'motopress-appointment' ),
			'people'    => esc_html__( 'Clients', 'motopress-appointment' ),
		);
	}

	/**
	 * @param string $columnName
	 * @param Booking $entity
	 *
	 * @since 1.0
	 */
	protected function displayValue( $columnName, $entity ) {
		switch ( $columnName ) {
			case 'status':
				echo '<span class="column-status-' . esc_attr( $entity->getStatus() ) . '">' . mpa_get_status_label( $entity->getStatus() ) . '</span>';
				break;

			case 'customer':
				$customer     = $entity->getCustomer();
				$customerInfo = array();

				if ( ! empty( $customer->getName() ) ) {
					$customerInfo[] = $customer->getName();
				}

				if ( ! empty( $customer->getEmail() ) ) {
					$customerInfo[] = '<a href="mailto:' . esc_attr( $customer->getEmail() ) . '">' . $customer->getEmail() . '</a>';
				}

				if ( ! empty( $customer->getPhone() ) ) {
					$customerInfo[] = '<a href="tel:' . esc_attr( $customer->getPhone() ) . '">' . $customer->getPhone() . '</a>';
				}

				if ( ! empty( $customerInfo ) ) {
					echo implode( '<br>', $customerInfo );
				} else {
					echo mpa_tmpl_placeholder();
				}

				break;

			case 'price':
				echo mpa_tmpl_price( $entity->getTotalPrice() );

				echo '<br>';

				// Translators: %s: Paid amount.
				$paidLabel   = sprintf( esc_html__( 'Paid: %s', 'motopress-appointment' ), mpa_tmpl_price_number( $entity->getPaidPrice() ) );
				$paymentsUrl = mpapp()->pages()->managePayments()->getUrl( array( 'booking_id' => $entity->getId() ) );

				printf( '<a href="%s">%s</a>', esc_url( $paymentsUrl ), $paidLabel );

				break;

			case 'services':
				// Pull employee names
				$services = array_map(
					function ( $reservation ) {
						$serviceName = get_the_title( $reservation->getServiceId() );
						return $serviceName ?: mpa_tmpl_placeholder();
					},
					$entity->getReservations()
				);

				if ( ! empty( $services ) ) {
					echo implode( '<br>', $services );
				} else {
					echo mpa_tmpl_placeholder();
				}

				break;

			case 'employees':
				// Pull employee names
				$employees = array_map(
					function ( $reservation ) {
						$employeeName = get_the_title( $reservation->getEmployeeId() );
						return $employeeName ?: mpa_tmpl_placeholder();
					},
					$entity->getReservations()
				);

				if ( ! empty( $employees ) ) {
					echo implode( '<br>', $employees );
				} else {
					echo mpa_tmpl_placeholder();
				}

				break;

			case 'time':
				// Pull dates
				$dates = array_map(
					function ( $reservation ) {
						$date = mpa_format_date( $reservation->getDate() );
						$time = $reservation->getServiceTime()->toString();

						return "{$date}, {$time}";
					},
					$entity->getReservations()
				);

				if ( ! empty( $dates ) ) {
					echo implode( '<br>', $dates );
				} else {
					echo mpa_tmpl_placeholder();
				}

				break;

			case 'people':
				$people = array_map(
					function ( $reservation ) {
						return $reservation->getCapacity(); },
					$entity->getReservations()
				);

				if ( ! empty( $people ) ) {
					echo implode( '<br>', $people );
				} else {
					echo mpa_tmpl_placeholder();
				}

				break;
		}
	}
}
