<?php

namespace MotoPress\Appointment\Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.3
 */
class Init {

	/**
	 * @since 1.15.2
	 */
	const WIDGET_CATEGORY_NAME = 'mpa-elementor-widgets';

	public function __construct() {
		// Check if the Elementor is active
		if ( ! did_action( 'elementor/loaded' ) ) {
			return;
		}

		if ( $this->isActiveLegacyElementor() ) {
			$this->addActionsLegacy();
		} else {
			$this->addActions();
		}
	}

	/**
	 * @since 1.15.2
	 */
	protected function isActiveLegacyElementor(): bool {
		if ( version_compare( ELEMENTOR_VERSION, '3.5.0', '>=' ) ) {
			return false;
		}

		return true;
	}

	/**
	 * @since 1.15.2
	 */
	protected function addActionsLegacy() {
		if ( ! version_compare( ELEMENTOR_VERSION, '2.2.4', '>=' ) &&
			// because our script is fired on the 'init' hook with priority 10,
			// while elementor is fired on the init hook with priority 0
			did_action( 'elementor/init' )
		) {
			$this->registerElementorCategoriesLegacy();
		}

		add_action( 'elementor/elements/categories_registered', array( $this, 'registerElementorCategoriesLegacy' ), 10 );
		add_action( 'elementor/widgets/widgets_registered', array( $this, 'registerElementorWidgetsLegacy' ), 10 );
	}

	/**
	 * @since 1.15.2
	 */
	protected function addActions() {
		add_filter( 'elementor/elements/categories_registered', array( $this, 'registerElementorCategories' ), 10, 1 );
		add_filter( 'elementor/widgets/register', array( $this, 'registerElementorWidgets' ), 10, 1 );
	}

	/**
	 * @since 1.15.2
	 */
	protected function widgets(): array {
		return apply_filters(
			'mpa_elementor_widgets',
			array(
				new Widgets\AppointmentFormWidget(),
				new Widgets\EmployeesListWidget(),
				new Widgets\LocationsListWidget(),
				new Widgets\ServiceCategoriesWidget(),
				new Widgets\ServicesListWidget(),
				new Widgets\EmployeeImageWidget(),
				new Widgets\EmployeeTitleWidget(),
				new Widgets\EmployeeServicesListWidget(),
				new Widgets\EmployeeScheduleWidget(),
				new Widgets\EmployeeContentWidget(),
				new Widgets\EmployeeContactsWidget(),
				new Widgets\EmployeeContactsWidget(),
				new Widgets\EmployeeSocialNetworksWidget(),
				new Widgets\EmployeeAdditionalInfoWidget(),
			)
		);
	}

	/**
	 * @protected
	 */
	public function registerElementorCategoriesLegacy() {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			self::WIDGET_CATEGORY_NAME,
			array(
				'title' => mpa_name(),
				'icon'  => 'font',
			)
		);
	}

	/**
	 * @protected
	 */
	public function registerElementorWidgetsLegacy() {
		foreach ( $this->widgets() as $widget ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( $widget );
		}
	}

	/**
	 * @protected
	 */
	public function registerElementorCategories( $elementsManager ) {
		$elementsManager->add_category(
			self::WIDGET_CATEGORY_NAME,
			array(
				'title' => mpa_name(),
				'icon'  => 'font',
			)
		);
	}

	/**
	 * @protected
	 */
	public function registerElementorWidgets( $widgetsManager ) {
		foreach ( $this->widgets() as $widget ) {
			$widgetsManager->register( $widget );
		}
	}
}
