<?php

namespace MotoPress\Appointment\Entities;

use MotoPress\Appointment\Structures\TimePeriod;
use DateTime;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.0
 */
class Reservation extends AbstractUniqueEntity {

	/**
	 * @var int
	 *
	 * @since 1.0
	 */
	protected $bookingId = 0;

	/**
	 * @var float
	 *
	 * @since 1.0
	 */
	protected $price = 0.0;

	/**
	 * @var DateTime
	 *
	 * @since 1.0
	 */
	protected $date = null;

	/**
	 * DO NOT USE THIS FIELD DIRECTLY
	 * IT WILL BE PROTECTED USE METHODS
	 * TODO: set it protected after woo payments plugin fix
	 * @var TimePeriod
	 *
	 * @since 1.0
	 */
	public $serviceTime = null;

	/**
	 * @var TimePeriod
	 *
	 * @since 1.0
	 */
	protected $bufferTime = null;

	/**
	 * DO NOT USE THIS FIELD DIRECTLY
	 * IT WILL BE PROTECTED USE METHODS
	 * TODO: set it protected after woo payments plugin fix
	 * @var int
	 *
	 * @since 1.0
	 */
	public $serviceId = 0;

	/**
	 * @var int
	 *
	 * @since 1.0
	 */
	protected $employeeId = 0;

	/**
	 * @var int
	 *
	 * @since 1.0
	 */
	protected $locationId = 0;

	/**
	 * @var int
	 *
	 * @since 1.0
	 */
	protected $capacity = 1;

	/**
	 * @var int[]
	 *
	 * @since 1.13.0
	 */
	protected $sentNotificationIds = array();

	/**
	 * @since 1.13.0
	 */
	public function getBookingId(): int {
		return $this->bookingId;
	}

	public function setBookingId( int $bookingId ) {
		$this->bookingId = $bookingId;
	}

	/**
	 * @return Booking|null
	 *
	 * @since 1.0
	 * @since 1.13.0 added the <code>$forceReload</code> argument.
	 */
	public function getBooking( $forceReload = false ) {
		if ( $this->bookingId > 0 ) {
			return mpa_get_booking( $this->bookingId, $forceReload );
		} else {
			return null;
		}
	}

	/**
	 * @return float
	 *
	 * @since 1.11.0
	 */
	public function getPrice(): float {
		return $this->price;
	}

	/**
	 * @return DateTime
	 *
	 * @since 1.11.0
	 */
	public function getDate(): DateTime {
		return $this->date;
	}

	/**
	 * @since 1.13.0
	 */
	public function getServiceTime(): TimePeriod {
		return $this->serviceTime;
	}

	/**
	 * @since 1.13.0
	 */
	public function getBufferTime(): TimePeriod {
		return $this->bufferTime;
	}

	/**
	 * @return int
	 *
	 * @since 1.11.0
	 */
	public function getServiceId(): int {
		return $this->serviceId;
	}

	/**
	 * @since 1.13.0
	 */
	public function getEmployeeId(): int {
		return $this->employeeId;
	}

	/**
	 * @since 1.13.0
	 */
	public function getLocationId(): int {
		return $this->locationId;
	}

	/**
	 * @since 1.13.0
	 */
	public function getCapacity(): int {
		return $this->capacity;
	}

	/**
	 * @return int[]
	 *
	 * @since 1.13.0
	 */
	public function getSentNotificationIds(): array {
		return $this->sentNotificationIds;
	}
}
