<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require 'functions/array.php';
require 'functions/conditional.php';
require 'functions/date.php';
require 'functions/entity.php';
require 'functions/filter.php';
require 'functions/format.php';
require 'functions/i18n.php';
require 'functions/misc.php';
require 'functions/plugin.php';
require 'functions/post-type.php';
require 'functions/regex.php';
require 'functions/request.php';
require 'functions/rest.php';
require 'functions/template.php';
require 'functions/time.php';
require 'functions/wordpress.php';


function mpa_get_upgrade_to_premium_page_url() {
	return admin_url( 'admin.php?page=mpa_premium' );
}

/**
 * @param string $wrapper - span by default. Pass the empty value to remove the wrapper
 */
function mpa_get_upgrade_to_premium_html_message( string $wrapper = 'p', string $wrapperClass = 'description' ): string {

	$message = sprintf(
		// translators: %s - is link to the Upgrade to Premium page in admin area.
		__( '<a href="%s">Upgrade to Premium</a> to enable this feature.', 'motopress-appointment' ),
		esc_url( mpa_get_upgrade_to_premium_page_url() )
	);

	if ( ! empty( $wrapper ) ) {

		$message = '<' . $wrapper . ' class="' . esc_attr( $wrapperClass ) . '">' . $message . '</' . $wrapper . '>';
	}

	return $message;
}

add_action(
	'admin_footer',
	function() {
		global $pagenow, $typenow;

		if ( 'edit.php' === $pagenow &&
			\MotoPress\Appointment\PostTypes\BookingPostType::POST_TYPE === $typenow ) {

			?>
			<script type="text/javascript">
				(function ( $ ) {
					var b = $( "#wpbody-content > .wrap > .wp-heading-inline + .page-title-action" );
					b.addClass("button-disabled");
					b.attr("href", "#");
					b.after('&nbsp;&nbsp;<?php echo wp_kses_post( mpa_get_upgrade_to_premium_html_message( 'span' ) ); ?>');
				})( jQuery );
			</script>
			<?php
		}
	},
	999
);

add_filter(
	'plugin_action_links_' . plugin_basename( \MotoPress\Appointment\PLUGIN_FILE ),
	function( $links ) {
		$links[] = '<a'
		. ' id="mphb-upgrade-plugin-link"'
		. ' href="' . esc_url( mpa_get_upgrade_to_premium_page_url() ) . '"'
		. ' style="color: #008000;"'
		. '>' . __( 'Upgrade', 'motopress-appointment' ) . '</a>';

		return $links;
	}
);

add_action(
	'admin_head',
	function() {
		?>
		<style>
			#adminmenu #toplevel_page_mpa_appointment_menu li:not(.current) a[href="admin.php?page=mpa_premium"] {
				color: #F8C130;
			}
		</style>
		<?php
	}
);
