<?php

namespace MotoPress\Appointment\Handlers;

use MotoPress\Appointment\Crons\AbandonPendingPaymentCron;
use MotoPress\Appointment\Crons\SendNotificationsCron;
use MotoPress\Appointment\Crons\DeleteDraftBookingsCron;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class CronsHandler {

	private $cronClasses = array(
		AbandonPendingPaymentCron::class,
		SendNotificationsCron::class,
		DeleteDraftBookingsCron::class,
	);


	public function __construct() {

		add_action(
			'cron_schedules',
			function( array $notDefaultCronSchedules ) {
				return $this->addCustomCronStartIntervals( $notDefaultCronSchedules );
			}
		);

		// add cron action hooks
		add_action(
			'plugins_loaded',
			function() {
				$this->initCrons();
			}
		);
	}


	private function addCustomCronStartIntervals( array $notDefaultCronSchedules ) {

		foreach ( $this->cronClasses as $cronClass ) {

			if ( empty( $notDefaultCronSchedules[ $cronClass::getCronStartIntervalId() ] ) ) {

				$notDefaultCronSchedules[ $cronClass::getCronStartIntervalId() ] = array(
					'interval' => $cronClass::getCronStartIntervalInSeconds(),
					'display'  => $cronClass::getCronStartIntervalDescription(),
				);
			}
		}

		return $notDefaultCronSchedules;
	}


	private function initCrons() {

		foreach ( $this->cronClasses as $cronClass ) {

			new $cronClass();
		}
	}

	public static function schedule_crons_after_plugin_activation() {

		AbandonPendingPaymentCron::schedule();
		SendNotificationsCron::schedule();
		DeleteDraftBookingsCron::schedule();
	}

	public static function unschedule_crons_before_plugin_deactivation() {

		AbandonPendingPaymentCron::unschedule();
		SendNotificationsCron::unschedule();
		DeleteDraftBookingsCron::unschedule();
	}
}
