<?php

namespace MotoPress\Appointment\Metaboxes\Booking;

use MotoPress\Appointment\Metaboxes\FieldsMetabox;
use MotoPress\Appointment\Services\BookingService;
use MotoPress\Appointment\Utils\BookingUtils;

use WP_Post;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.0
 */
class BookingPriceMetabox extends FieldsMetabox {

	/**
	 * @return string
	 *
	 * @since 1.0
	 */
	protected function theName(): string {
		return 'booking_price_metabox';
	}

	/**
	 * @since 1.0
	 *
	 * @return array
	 */
	protected function theFields() {
		$allowedCoupons = mpapp()->repositories()->coupon()->findAll( array( 'fields' => array( 'id' => 'code' ) ) );

		return array(
			'total_price'       => array(
				'type'  => 'price',
				'label' => esc_html__( 'Total Price', 'motopress-appointment' ),
			),
			'coupon_id'         => array(
				'type'    => 'select',
				'label'   => esc_html__( 'Coupon', 'motopress-appointment' ),
				'options' => mpa_no_value( 0 ) + $allowedCoupons,
				'default' => 0,
			),
			'reserved_services' => array(
				'type'  => 'edit-reservations',
				'label' => esc_html__( 'Reserved Services', 'motopress-appointment' ),
			),
			'payment_details'   => array(
				'type'  => 'payment-details',
				'label' => esc_html__( 'Payment Details', 'motopress-appointment' ),
			),
		);
	}

	/**
	 * @return string
	 *
	 * @since 1.0
	 */
	public function getLabel(): string {
		return esc_html__( 'Booking Price', 'motopress-appointment' );
	}

	protected function parseValues( int $postId, WP_Post $post ): array {
		$values = parent::parseValues( $postId, $post );

		// Parse reservations
		if ( isset( $_POST['reservations'] ) ) {
			$servicesField = $this->getField( 'reserved_services' );

			if ( ! is_null( $servicesField ) ) {
				// Validate and sanitize
				$servicesField->setValue( $_POST['reservations'], 'validate' );
				$values['reservations'] = $servicesField->getValue( 'save' );
			}
		}

		return $values;
	}

	/**
	 * @param array $values [add, update, delete, reservations]
	 * @param int $postId
	 * @param WP_Post $post
	 */
	protected function saveValues( array $values, int $postId, WP_Post $post ) {

		$booking                 = mpa_get_booking(); // Get data before the update
		$needsPriceRecalculation = false;

		parent::saveValues( $values, $postId, $post );

		// Update reservations
		if ( isset( $values['reservations'] ) && ! is_null( $booking ) ) {
			$bookingService = new BookingService();
			$bookingService->updateReservations( $booking, $values['reservations'] );

			// We need to update the price
			$needsPriceRecalculation = true;
		}

		// Do we need to update the price because of new coupon?
		if ( isset( $values['update']['_mpa_coupon_id'] ) && ! is_null( $booking )
			&& $values['update']['_mpa_coupon_id'] != $booking->getCouponId()
		) {
			$needsPriceRecalculation = true;
		}

		// Calculate the new price
		if ( $needsPriceRecalculation ) {
			// Get the fresh booking: new coupon, price, reservations etc.
			$booking = mpa_get_booking( 0, true );

			if ( ! is_null( $booking ) ) {
				BookingUtils::recalculateTotalPrice( $booking );
			}
		}
	}
}
