<?php

namespace MotoPress\Appointment\Payments\Gateways;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.5.0
 */
abstract class AbstractInstructionPaymentGateway extends AbstractPaymentGateway {

	/**
	 * @since 1.5.0
	 * @var string
	 */
	public $instructions = '';

	/**
	 * @since 1.5.0
	 */
	protected function setupProperties() {

		parent::setupProperties();

		$this->instructions = $this->getOption( 'instructions', $this->instructions );
	}

	/**
	 * @since 1.5.0
	 */
	public function printBillingFields() {

		if ( ! empty( $this->instructions ) ) {
			echo '<p>' . $this->instructions . '</p>';
		} else {
			echo '';
		}
	}

	/**
	 * @since 1.5.0
	 *
	 * @return array Raw field args.
	 */
	public function getFields() {

		$fields = parent::getFields();

		// Add instructions
		$fields[ $this->getOptionNameRaw( 'instructions' ) ] = array(
			'type'         => 'textarea',
			'label'        => esc_html__( 'Instructions', 'motopress-appointment' ),
			'description'  => esc_html__( 'Instructions for a customer on how to complete the payment.', 'motopress-appointment' ),
			'rows'         => 3,
			'size'         => 'large',
			'translatable' => true,
			'value'        => $this->instructions,
		);

		return $fields;
	}

	/**
	 * @since 1.5.0
	 *
	 * @param string $option
	 * @return bool
	 */
	protected function isTranslatableOption( $option ) {
		return parent::isTranslatableOption( $option ) || 'instructions' === $option;
	}
}
