<?php

namespace MotoPress\Appointment\Payments\Gateways;

use MotoPress\Appointment\Entities\Booking;
use MotoPress\Appointment\Entities\Payment;

use WP_Error;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.5.0
 */
interface PaymentGatewayInterface {

	/**
	 * @since 1.5.0
	 *
	 * @param Payment $payment
	 * @param array $args
	 *      @param Booking $args['booking']
	 * @return bool|WP_Error
	 */
	public function processPayment( $payment, $args);

	/**
	 * @since 1.5.0
	 */
	public function printBillingFields();

	/**
	 * @since 1.5.0
	 *
	 * @return array All additional data, required for a gateway to function
	 *      properly on the frontend.
	 */
	public function getFrontendData();

	/**
	 * @since 1.5.0
	 *
	 * @return string Unprefixed payment gateway ID.
	 */
	public function getId();

	/**
	 * @since 1.5.0
	 *
	 * @return string Gateway name / label.
	 */
	public function getName();

	/**
	 * @since 1.5.0
	 *
	 * @return string
	 */
	public function getPublicName();

	/**
	 * @since 1.5.0
	 *
	 * @return string
	 */
	public function getDescription();

	/**
	 * @since 1.5.0
	 *
	 * @return 'live'|'sandbox'
	 */
	public function getMode();

	/**
	 * @since 1.5.0
	 *
	 * @return array Raw field args.
	 */
	public function getFields();

	/**
	 * @since 1.5.0
	 *
	 * @return bool If true, then don't show this payment gateway on the
	 *      settings page.
	 */
	public function isInternal();

	/**
	 * @since 1.5.0
	 *
	 * @return bool
	 */
	public function isEnabled();

	/**
	 * @since 1.5.0
	 *
	 * @return bool Whether the item is enabled and supports current plugin
	 *      settings (like currency for payment gateways).
	 */
	public function isActive();

	/**
	 * @since 1.5.0
	 *
	 * @return bool Is sandbox enabled.
	 */
	public function isSandbox();

	/**
	 * @since 1.5.0
	 *
	 * @return bool
	 */
	public function isSupportsSandbox();

	/**
	 * @since 1.14.0
	 *
	 * @return bool
	 */
	public function isOnlinePayment();
}
