<?php

namespace MotoPress\Appointment\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class PluginPatcher {

	const OPTION_DB_VERSION = 'mpa_db_version';

	// IMPORTANT: add patch classes in the order of their versions!
	private $patchClasses = array(
		PluginPatch_1_4_0::class,
		PluginPatch_1_5_0::class,
		PluginPatch_1_11_0::class,
		PluginPatch_1_17_0::class,
	);

	public function __construct() {

		add_action(
			'init',
			function() {
				$this->executeNecessaryPatches();
			}
		);
	}

	private function executeNecessaryPatches() {

		$pluginDBVersion      = get_option( static::OPTION_DB_VERSION, null );
		$currentPluginVersion = mpapp()->getVersion();

		if ( empty( $pluginDBVersion ) ) {

			// plugin just activated so we do not need to execute any patches
			update_option( static::OPTION_DB_VERSION, $currentPluginVersion );
			return;
		}

		if ( version_compare( $pluginDBVersion, $currentPluginVersion, '=' ) ) {

			return;
		}

		mpa_set_time_limit( 0 );

		try {

			foreach ( $this->patchClasses as $patchClass ) {

				if ( version_compare( $pluginDBVersion, $patchClass::getVersion(), '<' ) ) {

					$patchClass::execute();

					$pluginDBVersion = $patchClass::getVersion();
					update_option( static::OPTION_DB_VERSION, $pluginDBVersion );
				}
			}

			update_option( static::OPTION_DB_VERSION, $currentPluginVersion );

		} catch ( \Throwable $e ) {

			// phpcs:ignore WordPress.PHP.DevelopmentFunctions.error_log_error_log
			error_log( '### PATCH ERROR: ' . $e->getMessage() . PHP_EOL . $e->getTraceAsString() );
		}
	}
}
