<?php

namespace MotoPress\Appointment\Repositories;

use MotoPress\Appointment\Entities\Booking;
use MotoPress\Appointment\Entities\Customer;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.0
 *
 * @see Booking
 */
class BookingRepository extends AbstractRepository {

	/**
	 * @param Booking|int $booking Booking or ID.
	 * @param float $newPrice
	 */
	public function savePrice( $booking, float $newPrice ) {

		$bookingId = is_object( $booking ) ? $booking->getId() : $booking;

		$saved = update_post_meta( $bookingId, '_mpa_total_price', $newPrice );

		if ( is_object( $booking ) && $saved ) {
			$booking->setTotalPrice( $newPrice );
		}
	}

	/**
	 * @return array
	 *
	 * @since 1.0
	 */
	protected function entitySchema() {

		return array(
			'post'     => array( 'ID', 'post_status' ),
			'postmeta' => array(
				'_mpa_uid'            => true,
				'_mpa_total_price'    => true,
				'_mpa_customer_name'  => true,
				'_mpa_customer_email' => true,
				'_mpa_customer_phone' => true,
				'_mpa_customer_notes' => true,
				'_mpa_coupon_id'      => true,
			),
		);
	}

	/**
	 * @param array $postData
	 * @return Booking
	 *
	 * @since 1.0
	 */
	protected function mapPostDataToEntity( $postData ) {

		$id = (int) $postData['ID'];

		$customerFields = array(
			'name'  => $postData['customer_name'],
			'email' => $postData['customer_email'],
			'phone' => $postData['customer_phone'],
		);

		$fields = array(
			'uid'           => $postData['uid'],
			'status'        => $postData['post_status'],
			'totalPrice'    => (float) $postData['total_price'],
			'reservations'  => mpapp()->repositories()->reservation()->findAllByBooking( $id ),
			'customer'      => new Customer( $id, $customerFields ),
			'customerNotes' => $postData['customer_notes'],
			'couponId'      => (int) $postData['coupon_id'],
		);

		return new Booking( $id, $fields );
	}
}
