<?php
/**
 * @package MotoPress\Appointment\Rest
 * @since 1.8.0
 */

namespace MotoPress\Appointment\Rest\Data;

use MotoPress\Appointment\Entities\Booking;

class BookingData extends AbstractPostData {

	/**
	 * @var Booking
	 */
	public $entity;

	public static function getRepository() {
		return mpapp()->repositories()->booking();
	}

	public static function getProperties() {
		$statusModel = mpapp()->postTypes()->booking()->statuses();

		return array(
			'id'           => array(
				'description' => 'Unique identifier for the resource.',
				'type'        => 'integer',
				'context'     => array( 'embed', 'view', 'edit' ),
				'readonly'    => true,
			),
			'uid'          => array(
				'description' => 'Booking uid.',
				'type'        => 'string',
				'context'     => array( 'view', 'edit' ),
				'readonly'    => true,
			),
			'status'       => array(
				'description' => 'Booking status.',
				'type'        => 'string',
				'context'     => array( 'embed', 'view', 'edit' ),
				'enum'        => array( $statusModel::STATUS_PENDING, $statusModel::STATUS_CANCELLED, $statusModel::STATUS_ABANDONED, $statusModel::STATUS_CONFIRMED ),
				'default'     => mpapp()->postTypes()->booking()->statuses()->getDefaultManualStatus(),
			),
			'reservations' => array(
				'description' => 'The date the booking was created, as UTC.',
				'type'        => 'array',
				'context'     => array( 'view', 'edit' ),
				'readonly'    => true,
				'items'       => array(
					'type'     => 'integer',
					'readonly' => true,
				),
			),
			'customer'     => array(
				'description' => 'Customer Information.',
				'type'        => 'object',
				'context'     => array( 'embed', 'view', 'edit' ),
				'properties'  => array(
					'name'  => array(
						'description' => 'Name.',
						'type'        => 'string',
						'context'     => array( 'embed', 'view', 'edit' ),
					),
					'email' => array(
						'description' => 'Email.',
						'oneOf'       => array(
							array(
								'type'   => 'string',
								'format' => 'email',
							),
							array(
								'type'      => 'string',
								'maxLength' => 0,
							),
						),
						'context'     => array( 'embed', 'view', 'edit' ),
					),
					'phone' => array(
						'description' => 'Phone.',
						'type'        => 'string',
						'context'     => array( 'embed', 'view', 'edit' ),
					),
				),
			),
			'total_price'  => array(
				'description' => 'Total price.',
				'type'        => 'number',
				'context'     => array( 'view', 'edit' ),
				'readonly'    => true,
			),
		);
	}

	public function getReservations() {
		return array_map(
			function ( $reservation ) {
				return $reservation->getId();
			},
			$this->entity->getReservations()
		);
	}

	public function getCustomer() {
		return array(
			'name'  => $this->entity->getCustomer()->getName(),
			'email' => $this->entity->getCustomer()->getEmail(),
			'phone' => $this->entity->getCustomer()->getPhone(),
		);
	}
}
