<?php

namespace MotoPress\Appointment\Shortcodes\DirectLinkActions;

class BookingDetails extends AbstractDirectLinkEntityShortcode {

	protected function name() {
		return 'booking_details';
	}

	public function getLabel() {
		return esc_html__( 'Booking Details', 'motopress-appointment' );
	}

	protected function getBookingInfoMarkup( $booking ) {
		return '<div class="mpa-booking-details">
			<div class="booking-id">
				<span class="label">' . esc_html__( 'Booking', 'motopress-appointment' ) . ': </span>
				<span class="value">#' . $booking->getId() . '</span>
			</div>
			<div class="booking-status ' . $booking->getStatus() . '">
				<span class="label">' . esc_html__( 'Status', 'motopress-appointment' ) . ': </span>
				<span class="value">' . $booking->getStatus() . '</span>
			</div>
			<div class="booking-total-price">
				<span class="label">' . esc_html__( 'Total Price', 'motopress-appointment' ) . ': </span>
				<span class="value">' . mpa_tmpl_price( $booking->getTotalPrice() ) . '</span>
			</div>
			<div class="booking-total-paid">
				<span class="label">' . esc_html__( 'Total Paid', 'motopress-appointment' ) . ': </span>
				<span class="value">' . mpa_tmpl_price( $booking->getPaidPrice(), array( 'literal_free' => false ) ) . '</span>
			</div>
		</div>';
	}

	protected function getContent( $booking ) {
		return '<h3 class="mpa-shortcode-title">' . esc_html__( 'Booking Details', 'motopress-appointment' ) . '</h3>
		<div class="mpa-booking-details-section booking-info">' . $this->getBookingInfoMarkup( $booking ) . '</div>
		<div class="mpa-booking-details-section booking-customer">' . $this->getCustomerMarkup( $booking ) . '</div>
		<div class="mpa-booking-details-section booking-reservations">' . $this->getReservationsMarkup( $booking ) . '</div>';
	}

	private function getReservationsMarkup( $booking ) {
		$reservationsMarkup = '';
		$reservations       = $booking->getReservations();

		if ( ! count( $reservations ) ) {
			return $reservationsMarkup;
		}

		$reservationsMarkup .= '<div class="reservations">';

		foreach ( $reservations as $reservation ) {
			$reservationsMarkup .= '<div class="reservation">
				<div class="reservation-details">
					<div class="reservation-title">
						<span class="label">' . esc_html__( 'Service', 'motopress-appointment' ) . ': </span>
						<span class="value">' . get_the_title( $reservation->getServiceId() ) . '</span>
					</div>
					<div class="reservation-date">
						<span class="label">' . esc_html__( 'Date', 'motopress-appointment' ) . ': </span>
						<span class="value">' . mpa_format_date( $reservation->getDate() ) . '</span>
					</div>
					<div class="reservation-time">
						<span class="label">' . esc_html__( 'Time', 'motopress-appointment' ) . ': </span>
						<span class="value">' . $reservation->getServiceTime()->toString() . '</span>
					</div>
				</div>
			</div>';
		}

		$reservationsMarkup .= '</div>';

		return $reservationsMarkup;
	}

	private function getCustomerMarkup( $booking ) {
		$customer = $booking->getCustomer();
		return '<div class="mpa-booking-details">
			<div class="booking-customer-name">
				<span class="label">' . esc_html__( 'Name', 'motopress-appointment' ) . ': </span>
				<span class="value">' . $customer->getName() . '</span>
			</div>
			<div class="booking-customer-email">
				<span class="label">' . esc_html__( 'Email', 'motopress-appointment' ) . ': </span>
				<span class="value"><a href="mailto:' . $customer->getEmail() . '">' . $customer->getEmail() . '</a></span>
			</div>
			<div class="booking-customer-phone">
				<span class="label">' . esc_html__( 'Phone', 'motopress-appointment' ) . ': </span>
				<span class="value"><a href="tel:' . $customer->getPhone() . '">' . $customer->getPhone() . '</a></span>
			</div>
		</div>';
	}
}
